//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[YakuSerializer](index.md)/[descriptor](descriptor.md)

# descriptor

[common]\
open override val [descriptor](descriptor.md): SerialDescriptor
